r51 - in trunk/www.openmoko.com: . textpattern

roh at sita.openmoko.org roh at sita.openmoko.org
Tue Jun 12 05:10:11 CEST 2007


Author: roh
Date: 2007-06-12 05:10:10 +0200 (Tue, 12 Jun 2007)
New Revision: 51

Modified:
   trunk/www.openmoko.com/index.php
   trunk/www.openmoko.com/textpattern/index.php
   trunk/www.openmoko.com/textsize.php
Log:
clean up common code


Modified: trunk/www.openmoko.com/index.php
===================================================================
--- trunk/www.openmoko.com/textsize.php	2007-06-06 08:58:38 UTC (rev 50)
+++ trunk/www.openmoko.com/textsize.php	2007-06-12 03:10:10 UTC (rev 51)
@@ -15,7 +15,7 @@
 	setcookie('openmoko_fontsize',$current_size);
 	
 	if (!$redirect_url) {
-		header('Location: '.PROTOCOL.OPENMOKO_WEB_HOST.OPENMOKO_WEB_WS_PATH);
+		header('Location: ' . om_href_link( OPENMOKO_WEB_HOST, OPENMOKO_WEB_WS_PATH ) );
 	} else {
 		header("Location: ".$redirect_url);
 	}	





More information about the webdesign-commitlog mailing list
--- trunk/www.openmoko.com/index.php	2007-06-06 08:58:38 UTC (rev 50)
+++ trunk/www.openmoko.com/index.php	2007-06-12 03:10:10 UTC (rev 51)
@@ -13,9 +13,10 @@
 			unset($$name);
 	define("txpinterface", "public");
 
 	// NOTE: to use constants from our openmoko_common_cfg.php in config.php
 	// we have to make sure it gets loaded before config.php is used.
-	require_once '../openmoko_common_cfg.php';
+	require_once '../openmoko_config-inc.php';
+	require_once '../openmoko_common-inc.php';
 
 
 	// Use buffering to ensure bogus whitespace in config.php is ignored
@@ -13,9 +13,10 @@
 	define("txpinterface", "public");
 
-	// NOTE: to use constants from our openmoko_common_cfg.php in config.php
+	// NOTE: to use constants from our openmoko_config-inc.php in config.php
 	// we have to make sure it gets loaded before config.php is used.

Modified: trunk/www.openmoko.com/textpattern/index.php
===================================================================
--- trunk/www.openmoko.com/textpattern/index.php	2007-06-06 08:58:38 UTC (rev 50)
+++ trunk/www.openmoko.com/textpattern/index.php	2007-06-12 03:10:10 UTC (rev 51)
@@ -23,9 +23,10 @@
 	$thisversion = '4.0.4';
 	$txp_using_svn = false; // set false for releases
 
 	// NOTE: to use constants from our openmoko_common_cfg.php in config.php
  	// we have to make sure it gets loaded before config.php is used.
-	require_once '../../openmoko_common_cfg.php';
+	require_once '../../openmoko_config-inc.php';
+	require_once '../../openmoko_common-inc.php';
 
 	ob_start(NULL, 2048);
 	if (!@include './config.php') { 
@@ -23,9 +23,10 @@
 	$txp_using_svn = false; // set false for releases
 
-	// NOTE: to use constants from our openmoko_common_cfg.php in config.php
+	// NOTE: to use constants from our openmoko_config-inc.php in config.php
  	// we have to make sure it gets loaded before config.php is used.

Modified: trunk/www.openmoko.com/textsize.php
===================================================================